@@ -49,14 +49,14 @@
 #' suppressPackageStartupMessages(library(dplyr))
 #' suppressPackageStartupMessages(library(recipes))
 #'
-#' len_out    = 10
-#' by_unit    = "month"
-#' start_date = as.Date("2021-01-01")
+#' len_out <- 10
+#' by_unit <- "month"
+#' start_date <- as.Date("2021-01-01")
 #'
 #' data_tbl <- tibble(
 #'   date_col = seq.Date(from = start_date, length.out = len_out, by = by_unit),
-#'   a    = rnorm(len_out),
-#'   b    = runif(len_out)
+#'   a = rnorm(len_out),
+#'   b = runif(len_out)
 #' )
 #'
 #' # Create a recipe object
@@ -81,112 +81,108 @@
 
 step_hai_hyperbolic <- function(recipe,
                                 ...,
-                                role       = "predictor",
-                                trained    = FALSE,
-                                columns    = NULL,
-                                scale_type = c("sin","cos","tan", "sincos"),
-                                skip       = FALSE,
-                                id         = rand_id("hai_hyperbolic")
-){
+                                role = "predictor",
+                                trained = FALSE,
+                                columns = NULL,
+                                scale_type = c("sin", "cos", "tan", "sincos"),
+                                skip = FALSE,
+                                id = rand_id("hai_hyperbolic")) {
+  terms <- recipes::ellipse_check(...)
+  funcs <- c("sin", "cos", "tan", "sincos")
+  if (!(scale_type %in% funcs)) {
+    rlang::abort("`func` should be either `sin`, `cos`, `sincos` or `tan`")
+  }
 
-    terms <- recipes::ellipse_check(...)
-    funcs <- c("sin", "cos", "tan", "sincos")
-    if (!(scale_type %in% funcs))
-        rlang::abort("`func` should be either `sin`, `cos`, `sincos` or `tan`")
-
-    recipes::add_step(
-        recipe,
-        step_hai_hyperbolic_new(
-            terms      = terms,
-            role       = role,
-            trained    = trained,
-            columns    = columns,
-            scale_type = scale_type,
-            skip       = skip,
-            id         = id
-        )
+  recipes::add_step(
+    recipe,
+    step_hai_hyperbolic_new(
+      terms      = terms,
+      role       = role,
+      trained    = trained,
+      columns    = columns,
+      scale_type = scale_type,
+      skip       = skip,
+      id         = id
     )
+  )
 }
 
 step_hai_hyperbolic_new <-
-    function(terms, role, trained, columns, scale_type, skip, id){
-
-        recipes::step(
-            subclass   = "hai_hyperbolic",
-            terms      = terms,
-            role       = role,
-            trained    = trained,
-            columns    = columns,
-            scale_type = scale_type,
-            skip       = skip,
-            id         = id
-        )
-
-    }
+  function(terms, role, trained, columns, scale_type, skip, id) {
+    recipes::step(
+      subclass   = "hai_hyperbolic",
+      terms      = terms,
+      role       = role,
+      trained    = trained,
+      columns    = columns,
+      scale_type = scale_type,
+      skip       = skip,
+      id         = id
+    )
+  }
 
 #' @export
 prep.step_hai_hyperbolic <- function(x, training, info = NULL, ...) {
+  col_names <- recipes::recipes_eval_select(x$terms, training, info)
 
-    col_names <- recipes::recipes_eval_select(x$terms, training, info)
+  value_data <- info[info$variable %in% col_names, ]
 
-    value_data <- info[info$variable %in% col_names, ]
-
-    if(any(value_data$type != "numeric")){
-        rlang::abort(
-            paste0("All variables for `step_hai_hyperbolic` must be `numeric`",
-                   "`integer` `double` classes.")
-        )
-    }
-
-    step_hai_hyperbolic_new(
-        terms      = x$terms,
-        role       = x$role,
-        trained    = TRUE,
-        columns    = col_names,
-        scale_type = x$scale_type,
-        skip       = x$skip,
-        id         = x$id
+  if (any(value_data$type != "numeric")) {
+    rlang::abort(
+      paste0(
+        "All variables for `step_hai_hyperbolic` must be `numeric`",
+        "`integer` `double` classes."
+      )
     )
+  }
 
+  step_hai_hyperbolic_new(
+    terms      = x$terms,
+    role       = x$role,
+    trained    = TRUE,
+    columns    = col_names,
+    scale_type = x$scale_type,
+    skip       = x$skip,
+    id         = x$id
+  )
 }
 
 #' @export
-bake.step_hai_hyperbolic <- function(object, new_data, ...){
-
-    make_call <- function(col, scale_type){
-        rlang::call2(
-            "hai_hyperbolic_vec",
-            .x            = rlang::sym(col)
-            , .scale_type = scale_type
-            , .ns         = "healthyR.ai"
-        )
-    }
-
-    grid <- expand.grid(
-        col                = object$columns
-        , scale_type       = object$scale_type
-        , stringsAsFactors = FALSE
+bake.step_hai_hyperbolic <- function(object, new_data, ...) {
+  make_call <- function(col, scale_type) {
+    rlang::call2(
+      "hai_hyperbolic_vec",
+      .x = rlang::sym(col),
+      .scale_type = scale_type,
+      .ns = "healthyR.ai"
     )
+  }
 
-    calls <- purrr::pmap(.l = list(grid$col, grid$scale_type), make_call)
+  grid <- expand.grid(
+    col = object$columns,
+    scale_type = object$scale_type,
+    stringsAsFactors = FALSE
+  )
 
-    # Column Names
-    newname <- paste0("hyperbolic_", grid$col, "_", grid$scale_type)
-    calls   <- recipes::check_name(calls, new_data, object, newname, TRUE)
+  calls <- purrr::pmap(.l = list(grid$col, grid$scale_type), make_call)
 
-    tibble::as_tibble(dplyr::mutate(new_data, !!!calls))
+  # Column Names
+  newname <- paste0("hyperbolic_", grid$col, "_", grid$scale_type)
+  calls <- recipes::check_name(calls, new_data, object, newname, TRUE)
 
+  tibble::as_tibble(dplyr::mutate(new_data, !!!calls))
 }
 
 #' @export
 print.step_hai_hyperbolic <-
-    function(x, width = max(20, options()$width - 35), ...) {
-        title <- "Hyperbolic Transformation on "
-        recipes::print_step(
-            x$columns, x$terms, x$trained, width = width, title = title
-        )
-        invisible(x)
-    }
+  function(x, width = max(20, options()$width - 35), ...) {
+    title <- "Hyperbolic Transformation on "
+    recipes::print_step(
+      x$columns, x$terms, x$trained,
+      width = width, title = title
+    )
+    invisible(x)
+  }
 
 #' Requited Packages
 #' @rdname required_pkgs.healthyR.ai
@@ -196,5 +192,5 @@ print.step_hai_hyperbolic <-
 # @noRd
 #' @export
 required_pkgs.step_hai_hyperbolic <- function(x, ...) {
-    c("healthyR.ai")
+  c("healthyR.ai")
 }
